@@ -1,7 +1,6 @@
 require 'spec_helper'
 
 describe 'neutron::plugins::ml2::ovn' do
-
   let :pre_condition do
     "class { '::neutron::keystone::authtoken':
       password => 'passw0rd',
@@ -23,13 +22,7 @@ describe 'neutron::plugins::ml2::ovn' do
     }
   end
 
-  let :test_facts do
-    { :operatingsystem           => 'default',
-      :operatingsystemrelease    => 'default'
-    }
-  end
-
-  shared_examples_for 'neutron ovn plugin' do
+  shared_examples 'neutron ovn plugin' do
 
     let :params do
       {}
@@ -40,19 +33,20 @@ describe 'neutron::plugins::ml2::ovn' do
     end
 
     it 'should perform default configuration of' do
-      is_expected.to contain_neutron_plugin_ml2('ovn/ovn_nb_connection').with_value(params[:ovn_nb_connection])
-      is_expected.to contain_neutron_plugin_ml2('ovn/ovn_sb_connection').with_value(params[:ovn_sb_connection])
-      is_expected.to contain_neutron_plugin_ml2('ovn/ovsdb_connection_timeout').with_value(params[:ovsdb_connection_timeout])
-      is_expected.to contain_neutron_plugin_ml2('ovn/neutron_sync_mode').with_value(params[:neutron_sync_mode])
-      is_expected.to contain_neutron_plugin_ml2('ovn/ovn_l3_mode').with_value(params[:ovn_l3_mode])
-      is_expected.to contain_neutron_plugin_ml2('ovn/vif_type').with_value(params[:vif_type])
-      is_expected.to contain_neutron_plugin_ml2('ovn/enable_distributed_floating_ip').with_value(params[:dvr_enabled])
-      is_expected.to contain_neutron_plugin_ml2('ovn/dns_servers').with_value(params[:dns_servers].join(','))
+      should contain_neutron_plugin_ml2('ovn/ovn_nb_connection').with_value(params[:ovn_nb_connection])
+      should contain_neutron_plugin_ml2('ovn/ovn_sb_connection').with_value(params[:ovn_sb_connection])
+      should contain_neutron_plugin_ml2('ovn/ovsdb_connection_timeout').with_value(params[:ovsdb_connection_timeout])
+      should contain_neutron_plugin_ml2('ovn/neutron_sync_mode').with_value(params[:neutron_sync_mode])
+      should contain_neutron_plugin_ml2('ovn/ovn_l3_mode').with_value(params[:ovn_l3_mode])
+      should contain_neutron_plugin_ml2('ovn/vif_type').with_value(params[:vif_type])
+      should contain_neutron_plugin_ml2('ovn/enable_distributed_floating_ip').with_value(params[:dvr_enabled])
+      should contain_neutron_plugin_ml2('ovn/dns_servers').with_value(params[:dns_servers].join(','))
+      should contain_neutron_plugin_ml2('ovn/vhost_sock_dir').with_value('<SERVICE DEFAULT>')
     end
 
   end
 
-  shared_examples_for 'Validating parameters' do
+  shared_examples 'Validating parameters' do
     let :params do
       {}
     end
@@ -60,18 +54,23 @@ describe 'neutron::plugins::ml2::ovn' do
     before :each do
       params.clear
       params.merge!(default_params)
+      params.merge!(:vhostuser_socket_dir => 'test')
     end
 
     it 'should fail with invalid neutron_sync_mode' do
       params[:neutron_sync_mode] = 'invalid'
-      is_expected.to raise_error(Puppet::Error, /Invalid value for neutron_sync_mode parameter/)
+      should raise_error(Puppet::Error, /Invalid value for neutron_sync_mode parameter/)
     end
 
     it 'should fail with invalid vif_type' do
       params[:vif_type] = 'invalid'
-      is_expected.to raise_error(Puppet::Error, /Invalid value for vif_type parameter/)
+      should raise_error(Puppet::Error, /Invalid value for vif_type parameter/)
       params.delete(:vif_type)
-      is_expected.to contain_neutron_plugin_ml2('ovn/vif_type').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_plugin_ml2('ovn/vif_type').with_value('<SERVICE DEFAULT>')
+    end
+
+    it 'should contain valid vhostuser socket dir' do
+      should contain_neutron_plugin_ml2('ovn/vhost_sock_dir').with_value('test')
     end
 
     context 'with DVR' do
@@ -79,7 +78,7 @@ describe 'neutron::plugins::ml2::ovn' do
         params.merge!(:dvr_enabled => true)
       end
       it 'should enable DVR mode' do
-        is_expected.to contain_neutron_plugin_ml2('ovn/enable_distributed_floating_ip').with_value(params[:dvr_enabled])
+        should contain_neutron_plugin_ml2('ovn/enable_distributed_floating_ip').with_value(params[:dvr_enabled])
       end
     end
   end
@@ -92,8 +91,8 @@ describe 'neutron::plugins::ml2::ovn' do
         facts.merge(OSDefaults.get_facts({:processorcount => 8}))
       end
 
-      it_configures 'neutron ovn plugin'
-      it_configures 'Validating parameters'
+      it_behaves_like 'neutron ovn plugin'
+      it_behaves_like 'Validating parameters'
     end
   end
 end
