@@ -68,6 +68,7 @@ describe 'neutron::server' do
       should contain_service('neutron-server').with_name('neutron-server')
       should contain_neutron_config('DEFAULT/api_workers').with_value(facts[:os_workers])
       should contain_neutron_config('DEFAULT/rpc_workers').with_value(facts[:os_workers])
+      should contain_neutron_config('DEFAULT/rpc_response_max_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/agent_down_time').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/enable_new_agents').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/router_scheduler_driver').with_value(p[:router_scheduler_driver])
@@ -165,7 +166,7 @@ describe 'neutron::server' do
         params.merge!(:dhcp_load_type => 'badvalue')
       end
 
-      it { should raise_error(Puppet::Error, /Must pass either networks, subnets, or ports as values for dhcp_load_type/) }
+      it { should raise_error(Puppet::Error) }
     end
 
     context 'with multiple service providers' do
